# Management Commands

Management commands require **Django Ninja** to be installed in Django's
`INSTALLED_APPS` setting:

```python
INSTALLED_APPS = [
    ...
    'ninja',
]
```

::: ninja.management.commands
    selection:
      filters:
        - "![A-Z]"
    rendering:
      show_root_toc_entry: False
